@@ -6,13 +6,13 @@ class Block:
 
 	progression = Blues.standard_blues
 	
-	bpm = 120
+	bpm = 220
 	iterations = 8
-	resolution = 8
+	resolution = 4
 
 	swing = True
 	key = 'E'
-	instruments = Bands.jazz
+	instruments = Bands.dummy
 
 	def get_bpm(self, iteration):
 		return self.bpm
