@@ -1,8 +1,13 @@
 #!/usr/bin/env python
 from Sequencer import Sequencer
 from Blocks import Block
-from mingus.extra import fluidsynth
 from os import sys
+try:
+	from mingus.extra import fluidsynth
+except:
+	print "Couldn't load the music library mingus."
+	print "A download is available at http://mingus.googlecode.com/"
+	sys.exit(1)
 
 if __name__ == '__main__':
 
