@@ -48,8 +48,7 @@ class Instrument:
 				self.playing = n
 				self.last_played = n
 				if state["paint_function"] != None:
-					for note in n:
-						state["paint_function"](note, self.params["channel"])
+					state["paint_function"](n, self.params["channel"])
 
 
 	def generate_note(self, state):
